package App::Greple::under::place;
use strict;
use warnings;

use App::Greple::under ':all';

1;

__DATA__

option default \
    -Munder \
    --use-custom-colormap \
    --place-line \
    --re '\A' --all
